/** @format */

import request from "@/utils/request";

// 查询人才库列列表
export function listList(query) {
  return request({
    url: "/talent/list/list",
    method: "get",
    params: query,
  });
}

// 查询人才库列详细
export function getListData(id) {
  return request({
    url: "/talent/list/" + id,
    method: "get",
  });
}

// 新增人才库列
export function addList(data) {
  return request({
    url: "/talent/list",
    method: "post",
    data: data,
  });
}

// 修改人才库列
export function updateList(data) {
  return request({
    url: "/talent/list",
    method: "put",
    data: data,
  });
}

// 删除人才库列
export function delList(id) {
  return request({
    url: "/talent/list/" + id,
    method: "delete",
  });
}

//保存注销信息
export function saveLogout(data) {
  return request({
    url: "/talent/list/zhuXiao",
    method: "post",
    data,
  });
}

//保存复核
export function saveReview(data) {
  return request({
    url: "/talent/list/updateFuHeJieZhiDate",
    method: "post",
    data,
  });
}

//人员导入
export function importDataA() {
  return request({
    url: "/talent/list/importDataA",
    method: "post",
  });
}
